@@ -12,23 +12,23 @@ class InertiaMiddleware:
         self.response = response
 
     def before(self):
-        self.request.is_inertia = self.request.header("HTTP_X_INERTIA")
+        self.request.is_inertia = self.request.header("X_INERTIA")
         if (
             self.request.is_inertia
             and self.request.method == "GET"
-            and self.request.header("HTTP_X_INERTIA_VERSION") != inertia_asset_version()
+            and self.request.header("X_INERTIA_VERSION") != inertia_asset_version()
         ):
             self.request.header("X-Inertia-Location", self.request.path)
             return self.response.view("", status=409)
 
     def after(self):
         if self.request.is_inertia:
-            self.request.header("Vary", "Accept")
-            self.request.header("X-Inertia", True)
+            self.response.header("Vary", "Accept")
+            self.response.header("X-Inertia", 'true')
 
             # use 303 response code when redirecting from PUT, PATCH, DELETE requests
             if (
                 self.request.method in ["PUT", "PATCH", "DELETE"]
-                and self.request.is_status(302)
+                and self.response.is_status(302)
             ):
-                self.request.status(303)
+                self.response.status(303)
